@@ -18,10 +18,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #ifndef __DISKLIST_H__
 #define __DISKLIST_H__
 
@@ -31,7 +30,9 @@
 //#include <kcontrol.h>
 
 // defines the os-type
-#include <qglobal.h>
+#include <QtCore/qglobal.h>
+//Added by qt3to4:
+#include <Qt3Support/Q3PtrList>
 
 #include "disks.h"
 
@@ -55,15 +56,15 @@
 #define SEPARATOR "|"
 
 /***************************************************************************/
-typedef QPtrList<DiskEntry>		DisksBase;
-typedef QPtrListIterator<DiskEntry>	DisksIterator;
+typedef Q3PtrList<DiskEntry>		DisksBase;
+typedef Q3PtrListIterator<DiskEntry>	DisksIterator;
 
 /***************************************************************************/
 class Disks : public DisksBase
 {
  public:
-  Disks(bool deepCopies=TRUE) { dc = deepCopies;};
-  ~Disks() { clear(); };
+  Disks(bool deepCopies=true) { dc = deepCopies;}
+  ~Disks() { clear(); }
 private:
   int compareItems( DiskEntry s1, DiskEntry s2 )
   {
@@ -73,7 +74,7 @@ private:
       ret = s1.mountPoint().compare(s2.mountPoint());
     }
 
-    kdDebug() << "compareDISKS " << s1.deviceName() << " vs " << s2.deviceName() << " (" << ret << ")" << endl;
+    kDebug() << "compareDISKS " << s1.deviceName() << " vs " << s2.deviceName() << " (" << ret << ")" ;
     return( ret );
   }
 
@@ -96,7 +97,7 @@ private:
 class DiskList : public QObject
 {  Q_OBJECT
 public:
-   DiskList( QObject *parent=0, const char *name=0 );
+   DiskList( QObject *parent=0 );
  ~DiskList();
    int readFSTAB();
    int readDF();
@@ -118,17 +119,17 @@ public slots:
   void applySettings();
 
 private slots:
-   void receivedDFStdErrOut(KProcess *, char *data, int len);
+   void receivedDFStdErrOut(K3Process *, char *data, int len);
    void dfDone();
 
 private:
   void replaceDeviceEntry(DiskEntry *disk);
 
   Disks            *disks;
-  KProcess         *dfProc;
+  K3Process         *dfProc;
   QString           dfStringErrOut;
   bool              readingDFStdErrOut;
-  KConfig           *config;
+  KSharedConfigPtr  config;
   bool              updatesDisabled;
   
 };
